@@ -1,34 +1,5 @@
 context("deprecated")
 
-test_that("vld_is", {
-  rlang::scoped_options(lifecycle_verbosity = "quiet")
-
-  expect_true(vld_is(1, "numeric"))
-  expect_false(vld_is(1L, "numeric"))
-  expect_true(vld_is(1L, "integer"))
-
-  x <- list()
-  class(x) <- c("a", "b")
-  expect_true(vld_is(x, "a"))
-  expect_true(vld_is(x, "b"))
-})
-
-test_that("chk_is", {
-  rlang::scoped_options(lifecycle_verbosity = "quiet")
-
-  expect_null(chk_is(1L, "integer"))
-  expect_invisible(chk_is(1L, "integer"))
-  expect_chk_error(chk_is(1, "integer"), "^`1` must inherit from class 'integer'[.]$")
-  expect_chk_error(
-    chk_is(matrix(1), "numeric"),
-    "`matrix[(]1[)]` must inherit from class 'numeric'[.]$"
-  )
-  x <- list()
-  class(x) <- c("a", "b")
-  expect_chk_error(chk_is(x, "c"), "`x` must inherit from class 'c'")
-  expect_chk_error(chk_is(x, "c", x_name = "c"), "C must inherit from class 'c'")
-})
-
 test_that("on", {
   rlang::scoped_options(lifecycle_verbosity = "quiet")
 
@@ -65,3 +36,26 @@ test_that("chk_no_missing", {
   expect_chk_error(chk_no_missing(NA), "^`NA` must not have missing values[.]$")
   expect_chk_error(chk_no_missing(NA, x_name = "1"), "^1 must not have missing values[.]$")
 })
+
+
+test_that("warning messages are generated for dep functions", {
+  rlang::scoped_options(lifecycle_verbosity = "warning")
+
+  expect_warning(chk_count(1))
+  expect_warning(chk_dirs(tempdir()))
+  expect_warning(chk_has(1:3, 1))
+  expect_warning(chk_in(1, 1:3))
+  expect_warning(chk_length(1))
+  expect_warning(chk_no_missing(1))
+  expect_warning(vld_no_missing(1))
+  expect_warning(chk_off())
+  expect_warning(chk_on())
+  expect_warning(is_chk_on())
+  expect_warning(chk_proportion(1))
+  expect_warning(deparse_backtick(2))
+
+  file <- tempfile()
+  writeLines(file, text = "some test data")
+  expect_warning(chk_files(file))
+})
+
