@@ -1,8 +1,10 @@
 test_that("chk_tz", {
   expect_null(chk_tz("UTC"))
   expect_invisible(chk_tz("UTC"))
-  expect_chk_error(chk_tz("TCU"),
-                   "^`\"TCU\"` must be a tz [(]non-missing scalar character of a recognized timezone[)][.]$")
+  expect_chk_error(
+    chk_tz("TCU"),
+    "^`\"TCU\"` must be a tz [(]non-missing scalar character of a recognized timezone[)][.]$"
+  )
 })
 
 test_that("vld_tz", {
